from nonebot.adapters.onebot.v11 import MessageEvent
from nonebot.params import ArgStr
from nonebot import on_command
from .data_source import calculate_acc

malody = on_command('/acc')

@malody.got("t", prompt='请输入要查询的段位(regular*|regular*v2|ex*|ex*v2|reform*)[*换成对应的数字或字母]')
@malody.got('accs', prompt='请按顺序输入acc如：99.26-98.63-97.32-96.11')
async def _(event: MessageEvent,t=ArgStr("t"),accs=ArgStr("accs")):
    accs=accs.strip().split("-")
    try:
        result=calculate_acc(accs[0],accs[1],accs[2],accs[3],t)
        acc1=str(result[0])[:5]
        acc2=str(result[1])[:5]
        acc3=str(result[2])[:5]
        acc4=str(result[3])[:5]
    except Exception as e:
        await malody.finish("失败，输入参数有误或不存在")
    await malody.finish("您的第一首acc是:{}%\n您的第二首acc是:{}%\n您的第三首acc是:{}%\n您的第四首acc是:{}%".format(acc1,acc2,acc3,acc4),at_sender=True)




from __future__ import division
from .jsondata import load_json

def calculate_acc(i1,i2,i3,i4,t):
    i1=float(i1)
    i2=float(i2)
    i3=float(i3)
    i4=float(i4)
    t=str(t)
    data=load_json()
    n1=int(data.get(t)[0])
    n2=int(data.get(t)[1])
    n3=int(data.get(t)[2])
    n4=int(data.get(t)[3])
    acc1=i1
    acc2=(i2*(n2+n1)-i1*n1)/n2
    acc3=(i3*(n3+n2+n1)-i2*(n2+n1))/n3
    acc4=(i4*(n4+n3+n2+n1)-i3*(n3+n2+n1))/n4
    return acc1,acc2,acc3,acc4


# -*- coding: utf-8 -*-
import setuptools

with open("README.md", "r",encoding="UTF-8") as f:
    long_description = f.read()

setuptools.setup(
    name="nonebot-plugin-acc-calculate",
    version="0.3.2",
    author="ohdmire",
    author_email="1750011571@qq.com",
    description="Nonebot2 段位单曲acc计算",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ohdmire/nonebot-plugin-acc-calculate",
    project_urls={
        "Bug Tracker": "https://github.com/ohdmire/nonebot-plugin-acc-calculate/issues",
    },
    packages=["nonebot_plugin_acc_calculate"],
    python_requires=">=3.8,<4.0",
    install_requires=[
        "nonebot2>=2.0.0a16",
        "nonebot-adapter-onebot>=2.0.0b1",
    ],
)